==> zio-aws-xray_2.13-5.17.130.6-sources.jar: zio/aws/xray/model/ListTagsForResourceRequest.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.xray.model.primitives.AmazonResourceName
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceRequest(
    resourceARN: AmazonResourceName,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
      .builder()
      .resourceARN(AmazonResourceName.unwrap(resourceARN): java.lang.String)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.xray.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.xray.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.ListTagsForResourceRequest =
      zio.aws.xray.model
        .ListTagsForResourceRequest(resourceARN, nextToken.map(value => value))
    def resourceARN: AmazonResourceName
    def nextToken: Option[String]
    def getResourceARN: ZIO[Any, Nothing, AmazonResourceName] =
      ZIO.succeed(resourceARN)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
  ) extends zio.aws.xray.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceARN: AmazonResourceName =
      zio.aws.xray.model.primitives.AmazonResourceName(impl.resourceARN())
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
  ): zio.aws.xray.model.ListTagsForResourceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-xray_2.13-5.17.167.1-sources.jar: zio/aws/xray/model/ListTagsForResourceRequest.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.xray.model.primitives.AmazonResourceName
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceRequest(
    resourceARN: AmazonResourceName,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
      .builder()
      .resourceARN(AmazonResourceName.unwrap(resourceARN): java.lang.String)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.xray.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.xray.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.ListTagsForResourceRequest =
      zio.aws.xray.model
        .ListTagsForResourceRequest(resourceARN, nextToken.map(value => value))
    def resourceARN: AmazonResourceName
    def nextToken: Optional[String]
    def getResourceARN: ZIO[Any, Nothing, AmazonResourceName] =
      ZIO.succeed(resourceARN)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
  ) extends zio.aws.xray.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceARN: AmazonResourceName =
      zio.aws.xray.model.primitives.AmazonResourceName(impl.resourceARN())
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.ListTagsForResourceRequest
  ): zio.aws.xray.model.ListTagsForResourceRequest.ReadOnly = new Wrapper(impl)
}
